@@ -29,7 +29,13 @@ int mod_gm_con_errors = 0;
 struct timeval mod_gm_error_time;
 double total_submit_sum = 0;
 double total_submit_max = 0;
-int total_submit_jobs = 0;
+double current_submit_max = 0;
+unsigned long total_submit_jobs = 0;
+unsigned long total_submit_jobs_delta = 0;
+unsigned long total_submit_errors = 0;
+unsigned long total_submit_errors_delta = 0;
+float current_submit_rate = 0;
+float current_avg_submit_duration = 0;
 struct timeval total_submit_time;
 extern mod_gm_opt_t *mod_gm_opt;
 
@@ -38,7 +44,6 @@ int create_worker( gm_server_t * server_list[GM_LISTSIZE], gearman_worker_st *wo
     int x = 0;
 
     gearman_return_t ret;
-    signal(SIGPIPE, SIG_IGN);
 
     gearman_worker_create( worker );
     if ( worker == NULL ) {
@@ -72,16 +77,22 @@ int worker_add_function( gearman_worker_st * worker, char * queue, gearman_worke
     return GM_OK;
 }
 
-
-/* create the gearman client */
+/* create the gearman client with non-blocking io */
 int create_client( gm_server_t * server_list[GM_LISTSIZE], gearman_client_st *client ) {
+    if(create_client_blocking(server_list,client ) != GM_OK) {
+        return GM_ERROR;
+    }
+    gearman_client_add_options( client, GEARMAN_CLIENT_NON_BLOCKING|GEARMAN_CLIENT_FREE_TASKS|GEARMAN_CLIENT_UNBUFFERED_RESULT);
+    return GM_OK;
+}
+
+/* create the gearman client with blocking io */
+int create_client_blocking( gm_server_t * server_list[GM_LISTSIZE], gearman_client_st *client ) {
     gearman_return_t ret;
     int x = 0;
 
     gm_log( GM_LOG_TRACE, "create_client()\n" );
 
-    signal(SIGPIPE, SIG_IGN);
-
     client = gearman_client_create(client);
     if ( client == NULL ) {
         gm_log( GM_LOG_ERROR, "Memory allocation failure on client creation\n" );
@@ -98,14 +109,16 @@ int create_client( gm_server_t * server_list[GM_LISTSIZE], gearman_client_st *cl
     }
     assert(x != 0);
 
-    gearman_client_set_timeout( client, mod_gm_opt->gearman_connection_timeout );
+    if(mod_gm_opt->gearman_connection_timeout > 0) {
+        gearman_client_set_timeout( client, mod_gm_opt->gearman_connection_timeout );
+    }
 
     return GM_OK;
 }
 
 
 /* create a task and send it */
-int add_job_to_queue( gearman_client_st *client, gm_server_t * server_list[GM_LISTSIZE], char * queue, char * uniq, char * data, int priority, int retries, int transport_mode, int log_stats_interval) {
+int add_job_to_queue( gearman_client_st *client, gm_server_t * server_list[GM_LISTSIZE], char * queue, char * uniq, char * data, int priority, int retries, int transport_mode, int async, int log_stats_interval) {
     gearman_job_handle_t job_handle;
     gearman_return_t rc;
     char * crypted_data;
@@ -126,9 +139,7 @@ int add_job_to_queue( gearman_client_st *client, gm_server_t * server_list[GM_LI
         return GM_ERROR;
     }
 
-    signal(SIGPIPE, SIG_IGN);
-
-    gm_log( GM_LOG_TRACE, "add_job_to_queue(%s, %s, %d, %d, %d)\n", queue, uniq, priority, retries, transport_mode);
+    gm_log( GM_LOG_TRACE, "add_job_to_queue(%s, %s, %d, %d, %d, %d, %d)\n", queue, uniq, priority, retries, transport_mode, async, log_stats_interval);
     gm_log( GM_LOG_TRACE, "%d --->%s<---\n", strlen(data), data );
 
     gettimeofday(&t1,NULL);
@@ -155,26 +166,36 @@ int add_job_to_queue( gearman_client_st *client, gm_server_t * server_list[GM_LI
     if(log_stats_interval > 0) {
         elapsed = elapsed_time(t1, t2);
         total_submit_sum += elapsed;
+        total_submit_jobs_delta++;
         total_submit_jobs++;
         if(elapsed > total_submit_max)
             total_submit_max = elapsed;
+        if(rc != GEARMAN_SUCCESS && rc != GEARMAN_IO_WAIT) {
+            total_submit_errors++;
+            total_submit_errors_delta++;
+        }
         if(t2.tv_sec >= total_submit_time.tv_sec + log_stats_interval) {
             if(total_submit_time.tv_sec > 0) {
-                gm_log(GM_LOG_INFO, "gearmand submission statistics: jobs:%7d   submit_rate: %6.1f/s   avg_submit_duration: %.6fs   max_submit_duration: %.6fs\n",
-                    total_submit_jobs,
-                    total_submit_jobs / elapsed_time(total_submit_time, t2),
-                    total_submit_sum/total_submit_jobs,
+                current_submit_rate = (total_submit_jobs_delta-total_submit_errors_delta) / elapsed_time(total_submit_time, t2);
+                current_avg_submit_duration = total_submit_sum/total_submit_jobs_delta;
+                current_submit_max = total_submit_max;
+                gm_log(GM_LOG_INFO, "gearmand submission statistics: jobs:%7d   errors: %7d   submit_rate: %6.1f/s   avg_submit_duration: %.6fs   max_submit_duration: %.6fs\n",
+                    total_submit_jobs_delta,
+                    total_submit_errors_delta,
+                    current_submit_rate,
+                    current_avg_submit_duration,
                     total_submit_max
                 );
-                total_submit_sum  = 0;
-                total_submit_jobs = 0;
-                total_submit_max  = 0;
+                total_submit_sum          = 0;
+                total_submit_jobs_delta   = 0;
+                total_submit_errors_delta = 0;
+                total_submit_max          = 0;
             }
             gettimeofday(&total_submit_time,NULL);
         }
     }
 
-    if(!gearman_success(rc)) {
+    if(rc != GEARMAN_SUCCESS && rc != GEARMAN_IO_WAIT) {
         /* log the error */
         if(retries == 0) {
             /* only log the first error, otherwise we would fill the log very quickly */
@@ -192,7 +213,11 @@ int add_job_to_queue( gearman_client_st *client, gm_server_t * server_list[GM_LI
 
         /* recreate client, otherwise gearman sigsegvs */
         gm_free_client( client );
-        create_client( server_list, client );
+        if(async) {
+            create_client( server_list, client );
+        } else {
+            create_client_blocking( server_list, client );
+        }
 
         /* retry as long as we have retries */
         if(retries > 0) {
@@ -203,7 +228,7 @@ int add_job_to_queue( gearman_client_st *client, gm_server_t * server_list[GM_LI
             } else {
                 gm_log( GM_LOG_TRACE, "add_job_to_queue() retrying... %d\n", retries );
             }
-            ret = add_job_to_queue( client, server_list, queue, uniq, data, priority, retries, transport_mode, log_stats_interval);
+            ret = add_job_to_queue( client, server_list, queue, uniq, data, priority, retries, transport_mode, async, log_stats_interval);
             return(ret);
         }
         /* no more retries... */
@@ -243,9 +268,7 @@ void gm_free_client(gearman_client_st *client) {
 void gm_free_worker(gearman_worker_st *worker) {
     gearman_worker_unregister_all(worker);
     gearman_worker_remove_servers(worker);
-    if(worker->options.is_allocated) {
-        gearman_worker_free(worker);
-    }
+    gearman_worker_free(worker);
 }
 
 /* get worker/jobs data from gearman server */
