@@ -318,7 +318,7 @@ int set_default_options(mod_gm_opt_t *opt) {
     }
     opt->exports_count = 0;
     opt->restrict_path_num      = 0;
-    opt->gearman_connection_timeout = -1;
+    opt->gearman_connection_timeout = 5000;
     for(i=0;i<GM_LISTSIZE;i++)
         opt->restrict_path[i] = NULL;
 
@@ -1025,6 +1025,8 @@ void dumpconfig(mod_gm_opt_t *opt, int mode) {
         gm_log( GM_LOG_DEBUG, "log mode:                        syslog (%d)\n", opt->logmode);
     if(opt->logmode == GM_LOG_MODE_TOOLS)
         gm_log( GM_LOG_DEBUG, "log mode:                        tools (%d)\n", opt->logmode);
+    if(opt->logmode == GM_LOG_MODE_CHECKS)
+        gm_log( GM_LOG_DEBUG, "log mode:            monitoring plugin (%d)\n", opt->logmode);
 
     if(mode == GM_WORKER_MODE) {
         gm_log( GM_LOG_DEBUG, "identifier:                      %s\n", opt->identifier);
@@ -1218,7 +1220,7 @@ void double2timeval(long double value, struct timeval *t) {
     t->tv_usec = (int)((value - (long double)t->tv_sec) * 1000000);
 }
 
-/* convert a timeval to double */
+/* convert a timeval to long double */
 long double timeval2double(struct timeval * t) {
     long double val = 0.0;
     if(t != NULL) {
@@ -1227,15 +1229,6 @@ long double timeval2double(struct timeval * t) {
     return val;
 }
 
-
-/* compare 2 timestructs */
-long mod_gm_time_compare(struct timeval * tv1, struct timeval * tv2) {
-   long secdiff = (long)(tv1->tv_sec - tv2->tv_sec);
-   long usecdiff = (long)(tv1->tv_usec - tv2->tv_usec);
-   return secdiff? secdiff: usecdiff;
-}
-
-
 /* set empty default job */
 int set_default_job(gm_job_t *job, mod_gm_opt_t *opt) {
 
@@ -1485,6 +1478,11 @@ void gm_log( int lvl, const char *text, ... ) {
     vsnprintf( buffer3, GM_BUFFERSIZE, text, ap );
     va_end( ap );
 
+    if ( debug_level >= GM_LOG_STDOUT || logmode == GM_LOG_MODE_CHECKS ) {
+        fprintf(stderr, "%s", buffer3 );
+        return;
+    }
+
     if ( debug_level >= GM_LOG_STDOUT || logmode == GM_LOG_MODE_TOOLS ) {
         printf( "%s", buffer3 );
         return;
@@ -1608,6 +1606,7 @@ void send_result_back(gm_job_t * exec_job) {
                          GM_JOB_PRIO_NORMAL,
                          GM_DEFAULT_JOB_RETRIES,
                          mod_gm_opt->transportmode,
+                         0,
                          0
                         ) == GM_OK) {
         gm_log( GM_LOG_TRACE, "send_result_back() finished successfully\n" );
@@ -1631,6 +1630,7 @@ void send_result_back(gm_job_t * exec_job) {
                               GM_JOB_PRIO_NORMAL,
                               GM_DEFAULT_JOB_RETRIES,
                               mod_gm_opt->transportmode,
+                              0,
                               0
                             ) == GM_OK) {
             gm_log( GM_LOG_TRACE, "send_result_back() finished successfully for duplicate server.\n" );
