@@ -29,6 +29,13 @@
 #include "gearman_utils.h"
 
 extern mod_gm_opt_t *mod_gm_opt;
+extern char hostname[GM_SMALLBUFSIZE];
+extern unsigned long total_submit_jobs;
+extern unsigned long total_submit_errors;
+extern float current_submit_rate;
+extern float current_avg_submit_duration;
+extern double current_submit_max;
+extern int result_threads_running;
 
 static const char *gearman_worker_source_name(void *source) {
     if(!source)
@@ -70,6 +77,7 @@ void *result_worker( void * data ) {
     gearman_return_t ret;
 
     gm_log( GM_LOG_TRACE, "worker %d started\n", *worker_num );
+    gethostname(hostname, GM_SMALLBUFSIZE-1);
 
     pthread_setcancelstate (PTHREAD_CANCEL_ENABLE, NULL);
     pthread_setcanceltype (PTHREAD_CANCEL_ASYNCHRONOUS, NULL);
@@ -95,7 +103,7 @@ void *result_worker( void * data ) {
 }
 
 /* put back the result into the core */
-void *get_results( gearman_job_st *job, void *context, size_t *result_size, gearman_return_t *ret_ptr ) {
+void *get_results( gearman_job_st *job, __attribute__((__unused__)) void *context, size_t *result_size, gearman_return_t *ret_ptr ) {
     int wsize, transportmode;
     char *workload;
     char *decrypted_data;
@@ -112,9 +120,6 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
     /* for calculating real latency */
     gettimeofday(&now,NULL);
 
-    /* contect is unused */
-    context = context;
-
     /* set size of result */
     *result_size = 0;
 
@@ -140,6 +145,24 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
     }
     mod_gm_decrypt(&decrypted_data, workload, transportmode);
 
+    if(!strcmp(workload, "check")) {
+        char * result = gm_malloc(GM_BUFFERSIZE);
+        *result_size = GM_BUFFERSIZE;
+        snprintf(result, GM_BUFFERSIZE, "0:OK - result worker running on %s. Sending %.1f jobs/s (avg duration:%.3fms). Version: %s|worker=%i;;;0;%i avg_submit_duration=%.6fs;;;0;%.6f jobs=%luc errors=%luc",
+                                            hostname,
+                                            current_submit_rate,
+                                            (current_avg_submit_duration*1000),
+                                            GM_VERSION,
+                                            result_threads_running,
+                                            mod_gm_opt->result_workers,
+                                            current_avg_submit_duration,
+                                            current_submit_max,
+                                            total_submit_jobs,
+                                            total_submit_errors
+        );
+        return((void*)result);
+    }
+
     if(decrypted_data == NULL) {
         *ret_ptr = GEARMAN_WORK_FAIL;
         return NULL;
@@ -158,10 +181,12 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
     if(mod_gm_opt->debug_result == GM_ENABLED) {
         FILE * fd;
         fd = fopen( "/tmp/last_result_received.txt", "w+" );
-        if(fd == NULL)
+        if(fd == NULL) {
             perror("fopen");
-        fputs( decrypted_data, fd );
-        fclose( fd );
+        } else {
+            fputs( decrypted_data, fd );
+            fclose( fd );
+        }
     }
 #endif
 
@@ -181,6 +206,7 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
     chk_result->engine              = &mod_gearman_check_engine;
     core_start_time.tv_sec          = 0;
     core_start_time.tv_usec         = 0;
+    chk_result->latency             = 0;
 
     while ( (ptr = strsep(&decrypted_data, "\n" )) != NULL ) {
         char *key   = strsep( &ptr, "=" );
@@ -237,7 +263,7 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
             string2timeval(value, &chk_result->start_time);
         } else if ( !strcmp( key, "finish_time" ) ) {
             string2timeval(value, &chk_result->finish_time);
-        } else if ( !strcmp( key, "latency" ) ) {
+        } else if ( !strcmp( key, "latency" ) ) { // used by send_gearman
             chk_result->latency = atof( value );
         }
     }
@@ -276,9 +302,9 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
 
     /* calculate real latency */
     now_f            = timeval2double(&now);
-    core_starttime_f = timeval2double(&core_start_time);
-    starttime_f      = timeval2double(&chk_result->start_time);
-    finishtime_f     = timeval2double(&chk_result->finish_time);
+    core_starttime_f = timeval2double(&core_start_time);            // time before job was sent to gearmand
+    starttime_f      = timeval2double(&chk_result->start_time);     // ts when check started on worker
+    finishtime_f     = timeval2double(&chk_result->finish_time);    // ts when check finished on worker
     exec_time        = finishtime_f - starttime_f;
     latency          = now_f - exec_time - core_starttime_f;
 
@@ -289,11 +315,6 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
 
     chk_result->latency += latency;
 
-#ifdef GM_DEBUG
-    if(chk_result->latency > 1000)
-        write_debug_file(&decrypted_orig);
-#endif
-
     /* this check is not a freshnes check */
     chk_result->check_options    = chk_result->check_options & ! CHECK_OPTION_FRESHNESS_CHECK;
 
@@ -309,16 +330,6 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
 #endif
         gm_log( GM_LOG_DEBUG, "service job completed: %s %s: exit %d, latency: %0.3f, exec_time: %0.3f\n", chk_result->host_name, chk_result->service_description, chk_result->return_code, chk_result->latency, exec_time );
     } else {
-#ifdef GM_DEBUG
-        /* does this host exist */
-/* TODO: this is done by core already! no need to do this twice */
-        host * hst = find_host( chk_result->host_name );
-        if(hst == NULL) {
-            write_debug_file(&decrypted_orig);
-            gm_log( GM_LOG_ERROR, "host '%s' could not be found\n", chk_result->host_name );
-            return NULL;
-        }
-#endif
         if(active_check) {
             host * hst = find_host( chk_result->host_name );
             if(hst != NULL) {
@@ -346,7 +357,9 @@ void *get_results( gearman_job_st *job, void *context, size_t *result_size, gear
 /* get the worker */
 int set_worker( gearman_worker_st *worker ) {
 
-    create_worker( mod_gm_opt->server_list, worker );
+    if(create_worker( mod_gm_opt->server_list, worker ) != GM_OK) {
+        return GM_ERROR;
+    }
 
     if ( mod_gm_opt->result_queue == NULL ) {
         gm_log( GM_LOG_ERROR, "got no result queue!\n" );
@@ -373,11 +386,13 @@ int set_worker( gearman_worker_st *worker ) {
 void write_debug_file(char ** text) {
     FILE * fd;
     fd = fopen( "/tmp/mod_gearman_result.txt", "a+" );
-    if(fd == NULL)
+    if(fd == NULL) {
         perror("fopen");
-    fputs( "------------->\n", fd );
-    fputs( *text, fd );
-    fputs( "\n<-------------\n", fd );
-    fclose( fd );
+    } else {
+        fputs( "------------->\n", fd );
+        fputs( *text, fd );
+        fputs( "\n<-------------\n", fd );
+        fclose( fd );
+    }
 }
 #endif
