@@ -100,7 +100,7 @@ int main (int argc, char **argv) {
         }
     }
     mod_gm_opt->debug_level = opt_verbose;
-    mod_gm_opt->logmode     = GM_LOG_MODE_TOOLS;
+    mod_gm_opt->logmode     = GM_LOG_MODE_CHECKS;
 
     if(server_list_num == 0) {
         printf("Error - no hostname given\n\n");
@@ -191,6 +191,10 @@ void print_usage() {
     printf("%%> ./check_gearman -H <job server hostname> -q perfdata -t 10 -x\n");
     printf("check_gearman CRITICAL - Queue perfdata has 155 jobs without any worker. |'perfdata_waiting'=155;10;100;0 'perfdata_running'=0 'perfdata_worker'=0;25;50;0\n");
     printf("\n");
+    printf("Check result worker:\n");
+    printf("%%> ./check_gearman -H <job server hostname> -q check_results -t 10 -s check\n");
+    printf("OK - result worker running on host. Sending 14.9 jobs/s (avg duration:0.040ms). Version: 4.0.3|worker=3;;;0;3 avg_submit_duration=0.000040s;;;0;0.000429 jobs=2388c errors=0c\n");
+    printf("\n");
 
     exit( STATE_UNKNOWN );
 }
@@ -335,7 +339,7 @@ int check_worker(char * queue, char * to_send, char * expect) {
     }
 
     /* create client */
-    if ( create_client( server_list, &client ) != GM_OK ) {
+    if ( create_client_blocking( server_list, &client ) != GM_OK ) {
         current_client = &client;
         printf("%s UNKNOWN - cannot create gearman client\n", PLUGIN_NAME);
         return( STATE_UNKNOWN );
@@ -365,6 +369,15 @@ int check_worker(char * queue, char * to_send, char * expect) {
                                                     &ret);
         }
 
+        if(opt_verbose) {
+            fprintf(stderr, "code:   %s\n", gearman_client_error(&client));
+            fprintf(stderr, "result: %s\n", result);
+        }
+
+        if (ret == GEARMAN_IO_WAIT) {
+            ret = gearman_client_wait(&client);
+        }
+
         if (ret == GEARMAN_WORK_DATA) {
             free(result);
             continue;
@@ -375,13 +388,8 @@ int check_worker(char * queue, char * to_send, char * expect) {
         else if (ret == GEARMAN_SUCCESS) {
             gm_free_client(&client);
         }
-        else if (ret == GEARMAN_WORK_FAIL) {
-            printf("%s CRITICAL - Job failed\n", PLUGIN_NAME);
-            gm_free_client(&client);
-            return( STATE_CRITICAL );
-        }
         else {
-            printf("%s CRITICAL - Job failed: %s\n", PLUGIN_NAME, gearman_client_error(&client));
+            printf("%s CRITICAL - job failed: %s\n", PLUGIN_NAME, gearman_client_error(&client));
             gm_free_client(&client);
             return( STATE_CRITICAL );
         }
@@ -400,7 +408,7 @@ int check_worker(char * queue, char * to_send, char * expect) {
     }
 
     // if result starts with a number followed by a colon, use this as exit code
-    if(strlen(result) > 1 && result[1] == ':') {
+    if(result != NULL && strlen(result) > 1 && result[1] == ':') {
         int rc = result[0] - '0';
         result += 2;
         printf("%s\n", result);
